# (TOPSIS)Technique for Order of Preference by Similarity to Ideal Solution 
It takes input from command line and creates a .csv file containing TOPSIS score and ranks.

## Installation
```pip install Topsis-Akshat-101917081```

## How to use it?
Open terminal and type the input in following format
python <program.py> <InputDataFile> <Weights> <Impacts> <ResultFileName>

## License

© 2022 Akshat Gupta

This repository is licensed under the MIT license. See LICENSE for details.